@@ -22,9 +22,10 @@
     msg = paste(temp$Package, ": ", temp$Title, "\n", "Version ", temp$Version,
                 " created on ", temp$Date, ".\n", sep = "")
     msg = paste(msg,
-"copyright (c) 2012, James M. Flegal, University of California,Riverside\n",
-"                    John Hughes, University of Minnesota\n",
-"                    Dootika Vats, University of Minnesota\n", sep = "")
+"copyright (c) 2012, James M. Flegal, University of California, Riverside\n",
+"                    John Hughes, University of Colorado, Denver\n",
+"                    Dootika Vats, University of Warwick\n", 
+"                    Ning Dai, University of Minnesota\n", sep = "")
     msg = paste(msg, 'For citation information, type citation("mcmcse").\n')
     msg = paste(msg, 'Type help("mcmcse-package") to get started.\n')
     packageStartupMessage(msg)
